package com.goldenwater.slaj.stan.service;

import java.util.List;
import com.goldenwater.slaj.stan.domain.ObjStanRevi;

public interface IObjStanReviService {
    ObjStanRevi selectObjStanReviByGuid(String guid);
    List<ObjStanRevi> selectObjStanReviList(ObjStanRevi entity);
    int insertObjStanRevi(ObjStanRevi entity);
    int updateObjStanRevi(ObjStanRevi entity);
    int deleteObjStanReviByGuid(String guid);
    int deleteObjStanReviByGuids(String[] guids);
}
